# lial-sms-library
Librairie qui permet d'interagir avec l'API d'envoi de SMS du lial

Lire la documentation : file:///A:/A3-Informatique/Techniciens/SIGIER%20Luc/documentation/lial_sms/html/index.html